@@ -3,13 +3,10 @@ from .plugins import *
 from .core import NAME
 
 
-del analyze, default, more, validate, string, transform
-
-
 def _main():
   from fire import Fire as _Fire
 
-  len = length
+  len = length  # command alias
 
   if __name__ == '__main__':
     _Fire(name=NAME)
